==> hamster_v.0.3.tgz: hamster_v.0.3/emitters/bf-emit-util.scm <==
;; BF Emit Utils
;; Jon Simons (simonsj at ccs dot neu dot edu)
;; August, 2007
;; -------------------------------------------------------------------------
;; This module provides utility functions for other emitter modules.
;; -------------------------------------------------------------------------
(module bf-emit-util mzscheme
  
  (provide pad
           mul-skip
           gen-loop
           (struct GENLOOP (start end)))
  
  ;; GENMUL Stuff ------------------------------------------------------------
  
  (define (gen-mul-skip)
    (let ((tmp-num (box 0)))
      (lambda ()
        (begin
          (set-box! tmp-num (+ 1 (unbox tmp-num)))
          (format "skip_mul_body_~v" (unbox tmp-num))))))

  ;; Used for generating skip labels for MULs
  (define mul-skip (gen-mul-skip))
               
  ;; GENLOOP Stuff -----------------------------------------------------------
  
  ;; Used for the starting and ending labels for loops.
  ;;
  ;; make-GENLOOP : string string -> GENLOOP
  (define-struct GENLOOP (start end))
  
  (define (gen-loop-wrap)
    (let ((tmp-num (box 0)))
      (lambda ()
        (begin
          (set-box! tmp-num (+ 1 (unbox tmp-num)))
          (make-GENLOOP (format "start_loop_~v" (unbox tmp-num))
                        (format "end_loop_~v" (unbox tmp-num)))))))
  
  (define gen-loop (gen-loop-wrap))
  
  ;; Pretty Print Stuff ------------------------------------------------------
   
  ;; Returns a string containg the given number of leading spaces
  ;; followed by the given string.
  ;;
  ;; pad : string number -> string
  (define (pad s n)
    (string-append (make-string n #\space) s))
  
  )

==> hamster_v.0.4.tgz: hamster_v.0.4/emitters/bf-emit-util.scm <==
;; BF Emit Utils
;; Jon Simons (simonsj at ccs dot neu dot edu)
;; August, 2007
;; -------------------------------------------------------------------------
;; This module provides utility functions for other emitter modules.
;; -------------------------------------------------------------------------
(module bf-emit-util mzscheme
  
  (provide pad
           mul-skip
           do-mul-skip
           gen-loop
           (struct GENLOOP (start do end)))
  
  ;; GENMUL Stuff ------------------------------------------------------------
  
  (define (gen-mul-skip)
    (let ((tmp-num (box 0)))
      (lambda ()
        (begin
          (set-box! tmp-num (+ 1 (unbox tmp-num)))
          (format "skip_mul_body_~v" (unbox tmp-num))))))

  ;; Used for generating skip labels for MULs
  (define mul-skip (gen-mul-skip))
  (define do-mul-skip (lambda ()
                        (string-append "do_" (mul-skip))))
               
  ;; GENLOOP Stuff -----------------------------------------------------------
  
  ;; Used for the starting and ending labels for loops.
  ;;
  ;; make-GENLOOP : string string string -> GENLOOP
  (define-struct GENLOOP (start do end))
  
  (define (gen-loop-wrap)
    (let ((tmp-num (box 0)))
      (lambda ()
        (begin
          (set-box! tmp-num (+ 1 (unbox tmp-num)))
          (make-GENLOOP (format "start_loop_~v" (unbox tmp-num))
                        (format "do_loop_~v" (unbox tmp-num))
                        (format "end_loop_~v" (unbox tmp-num)))))))
  
  (define gen-loop (gen-loop-wrap))
  
  ;; Pretty Print Stuff ------------------------------------------------------
   
  ;; Returns a string containing the given number of leading spaces
  ;; followed by the given string.
  ;;
  ;; pad : string number -> string
  (define (pad s n)
    (string-append (make-string n #\space) s))
  
  )
